'use strict'
var __awaiter =
  (this && this.__awaiter) ||
  function (thisArg, _arguments, P, generator) {
    function adopt(value) {
      return value instanceof P
        ? value
        : new P(function (resolve) {
            resolve(value)
          })
    }
    return new (P || (P = Promise))(function (resolve, reject) {
      function fulfilled(value) {
        try {
          step(generator.next(value))
        } catch (e) {
          reject(e)
        }
      }
      function rejected(value) {
        try {
          step(generator['throw'](value))
        } catch (e) {
          reject(e)
        }
      }
      function step(result) {
        result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected)
      }
      step((generator = generator.apply(thisArg, _arguments || [])).next())
    })
  }
const sqlite3 = require('sqlite3').verbose()
class SQLite3 {
  constructor(path) {
    this.db = null
    this.path = path
  }
  open() {
    return __awaiter(this, void 0, void 0, function* () {
      return new Promise((resolve, reject) => {
        this.db = new sqlite3.Database(this.path, function (err) {
          if (err) reject(err)
          else resolve(this.path + ' opened')
        })
      })
    })
  }
  run(query) {
    return __awaiter(this, void 0, void 0, function* () {
      return new Promise((resolve, reject) => {
        this.db.run(query, function (err) {
          if (err) reject(err)
          else resolve(true)
        })
      })
    })
  }
  get(query, params) {
    return __awaiter(this, void 0, void 0, function* () {
      return new Promise((resolve, reject) => {
        this.db.get(query, params, function (err, row) {
          if (err) reject(err)
          else resolve(row)
        })
      })
    })
  }
  all(query, params) {
    return __awaiter(this, void 0, void 0, function* () {
      return new Promise((resolve, reject) => {
        if (!params) params = []
        this.db.all(query, params, function (err, rows) {
          if (err) reject(err)
          else resolve(rows)
        })
      })
    })
  }
  each(query, params, action) {
    return __awaiter(this, void 0, void 0, function* () {
      return new Promise((resolve, reject) => {
        var db = this.db
        db.serialize(function () {
          db.each(query, params, function (err, row) {
            if (err) reject(err)
            else {
              if (row) {
                action(row)
              }
            }
          })
          resolve(true)
        })
      })
    })
  }
  close() {
    return __awaiter(this, void 0, void 0, function* () {
      return new Promise((resolve, reject) => {
        this.db.close(function (err) {
          if (err) reject(err)
          else resolve(true)
        })
      })
    })
  }
}
module.exports = SQLite3
