"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.close = exports.hasUnsubscribedEmail = exports.addUnsubscribedEmail = exports.clearAllRows = exports.setEmailSent = exports.getAllEmailRows = exports.getEmailRowsToBeSent = exports.addEmailRow = void 0;
const logger_1 = require("../utils/logger");
const db_model_1 = require("./db.model");
const db = db_model_1.getDB();
const stmt = db.prepare('CREATE TABLE IF NOT EXISTS messages (id INTEGER PRIMARY KEY AUTOINCREMENT, time datetime, template TEXT, sendFrom TEXT, sendTo TEXT, subject TEXT, body TEXT, sent INT)');
stmt.run();
const stmt2 = db.prepare('CREATE TABLE IF NOT EXISTS unsubscribed (id INTEGER PRIMARY KEY AUTOINCREMENT, email TEXT)');
stmt2.run();
const addEmailRow = (time, messageOptions) => {
    logger_1.log(`adding email row for ${time} with message: ${messageOptions.body}`);
    const { template, sendFrom, sendTo, subject, body } = messageOptions;
    const query = db.prepare('INSERT INTO messages (time,template,sendFrom,sendTo,subject,body, sent) VALUES (?,?,?,?,?,?,?)');
    try {
        query.run(time, template, sendFrom, sendTo, subject, body, 0);
    }
    catch (err) {
        logger_1.log(err);
    }
};
exports.addEmailRow = addEmailRow;
const getEmailRowsToBeSent = (time) => {
    const sql = db.prepare(`SELECT * FROM messages WHERE time <= datetime(?) AND sent=0`);
    let emails = [];
    try {
        emails = sql.all(time);
    }
    catch (err) {
        logger_1.log(err);
    }
    logger_1.log(`getting emails before time: ${emails.length}`);
    const emailsdb = emails;
    return emailsdb;
};
exports.getEmailRowsToBeSent = getEmailRowsToBeSent;
const getAllEmailRows = () => {
    const sql = db.prepare(`SELECT * FROM messages ORDER BY time`);
    let emails = [];
    try {
        emails = sql.all();
    }
    catch (err) {
        logger_1.log(err);
    }
    const emailsdb = emails;
    return emailsdb;
};
exports.getAllEmailRows = getAllEmailRows;
const setEmailSent = (id) => {
    const sql = db.prepare(`UPDATE messages SET sent = 1 WHERE id = ?`);
    try {
        sql.run(id);
    }
    catch (err) {
        logger_1.log(err);
    }
};
exports.setEmailSent = setEmailSent;
const clearAllRows = () => {
    const query = db.prepare('DELETE from messages');
    try {
        query.run();
    }
    catch (err) {
        logger_1.log(err);
    }
};
exports.clearAllRows = clearAllRows;
const close = () => {
    db.close();
};
exports.close = close;
const addUnsubscribedEmail = (email) => {
    const query = db.prepare('INSERT INTO unsubscribed (email) VALUES (?)');
    try {
        query.run(email);
    }
    catch (err) {
        logger_1.log(err);
    }
};
exports.addUnsubscribedEmail = addUnsubscribedEmail;
const hasUnsubscribedEmail = (email) => {
    const sql = db.prepare(`SELECT * FROM unsubscribed WHERE email = ?`);
    let emails = [];
    try {
        emails = sql.all(email);
    }
    catch (err) {
        logger_1.log(err);
    }
    return emails.length > 0;
};
exports.hasUnsubscribedEmail = hasUnsubscribedEmail;
